package com.ylcm.sys.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ylcm.sys.form.AdSpecialAnalysisBenchmarkingQueryForm;
import com.ylcm.sys.form.AdSpecialAnalysisQueryForm;
import com.ylcm.sys.vo.AdSpecialAnalysisBenchmarkingVO;
import com.ylcm.sys.vo.AdSpecialAnalysisVO;
import com.ylcm.sys.vo.AdSpecialDistVO;
import com.ylcm.sys.vo.AdSpecialTopVO;


public interface SpecialAnalysisService {
	/**
	 * 专题广告分析列表页
	 * @param queryForm
	 * @return
	 */
	IPage<AdSpecialAnalysisVO> page(AdSpecialAnalysisQueryForm queryForm);
	
	/**
	 * 专题top30
	 * @param type 0产品 1栏目
	 */
	List<AdSpecialTopVO> specialTop(Integer type,String startDate, String endDate);
	
	
	/**
	 * 投放媒体分布
	 * @param type
	 * @param productName
	 * @param startDate
	 * @param endDate
	 * @return
	 */
	List<AdSpecialDistVO> mediaDist(Integer type, String productName, String startDate, String endDate);
	
	/**
	 * 投放电视剧分布
	 * @param type
	 * @param productName
	 * @param startDate
	 * @param endDate
	 * @return
	 */
	List<AdSpecialDistVO> tvDist(Integer type, String productName, String startDate, String endDate);
	
	/**
	 * 二级行业广告投放品牌分布
	 * @param type
	 * @param launch 0 投放频次  1 投放频次 TOP10
	 * @param secondInd
	 * @param startDate
	 * @param endDate
	 * @return
	 */
	List<AdSpecialDistVO> secondIndDist(Integer type, Integer launch, String secondInd, String startDate, String endDate);
	
	/**
	 *     对标分析
	 * @param AdSpecialAnalysisBenchmarkingQueryForm
	 */
	IPage<AdSpecialAnalysisBenchmarkingVO> benchmarkingPage(AdSpecialAnalysisBenchmarkingQueryForm queryForm);
}
